@@ -24,11 +24,25 @@ class IsPrimeGame(object):
             self.step = self.step - 1
     
     def is_prime(self, n):
-        '''check if integer n is a prime'''
-        for x in range(2, int(n**0.5)+1):
-            if n % x == 0:
-                return False
+        '''check if integer n is a prime between 0 and 100'''
+        if n in [2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47,
+                 53, 59, 61, 67, 71, 73, 79, 83, 89, 97]:
             return True
+        return False
+    
+    #~ def calculate_is_prime(self, n):
+        #~ '''check if integer n is a prime by calculation (unused)'''
+        #~ if n == 2:
+          #~ return True
+        #~ if n % 2 == 0:
+          #~ return False
+        #~ max = n**0.5+1
+        #~ i = 3
+        #~ while i <= max:
+            #~ if n % i == 0:
+                #~ return False
+            #~ i+=2
+        #~ return True
     
     def evaluate(self, player):
         if self.is_prime(self.number):
