@@ -139,6 +139,7 @@ class ReactionFaceoff(object):
             self.aboutScreen = False
             self.helpScreen = False
             self.gamesScreen = False
+            self.pauseScreen = False
             self.ready1 = False
             self.ready2 = False
             self.playing = False
@@ -233,9 +234,11 @@ class ReactionFaceoff(object):
                     elif status == "return":
                         returnToMenu = True
                         break
-                    else:
-                        self.button1.draw()
-                        self.button2.draw()
+                    elif status == "pause":
+                        self.pauseScreen = True
+                        self.pause()
+                    self.button1.draw()
+                    self.button2.draw()
                     #~ self.display.blit(self.screen, (0,0))
                     pygame.display.flip()
                     clock.tick(30)
@@ -246,6 +249,16 @@ class ReactionFaceoff(object):
             self.clearPlayArea()
             self.finalizeGame()
     
+    def pause(self):
+        self.clearPlayArea()
+        self.drawMainText("Pause")
+        pygame.display.flip()
+        clock = pygame.time.Clock()
+        status = False
+        while not status:
+            status = self.handleEvents()
+            clock.tick(10)
+    
     def showAboutScreen(self):
         self.clearPlayArea()
         center = (self.screen.get_width()/2, self.screen.get_height()/2)
@@ -271,7 +284,7 @@ class ReactionFaceoff(object):
         
         You can disable games you want to avoid from the games menu.
         
-        Press Q to quit at any time, press R to return to the main menu during a game.
+        Press P to pause, Q to quit and R to return to the main menu during a game.
         ''', center, self.screen.get_height()-40, "right", size=30)
         self.button1.draw()
         self.button2.draw()
@@ -549,6 +562,9 @@ class ReactionFaceoff(object):
                 if event.key == K_r:
                     if self.playing:
                         return "return"
+                if event.key == K_p:
+                    if self.playing:
+                        return "pause"
             elif event.type == MOUSEBUTTONUP:
                 self.numberOfGamesS.sliding = False
             elif event.type == MOUSEBUTTONDOWN:
@@ -562,6 +578,8 @@ class ReactionFaceoff(object):
                         return True
                     elif self.gamesScreen:
                         return self.handleGameScreenEvent(event, x, y)
+                    elif self.pauseScreen:
+                        return True
                     else:    
                         if self.button1.collidepoint(x, y):
                             self.ready1 = True
